<?php

set_include_path('/usr/share/php/smarty3/');

require('Smarty.class.php');

$tpl = new Smarty();
$tpl->assign("htmladdress", 'iricartb@gmail.com"><h1>');
$tpl->assign("jsaddress", 'iricartb@gmail.com">iricartb@gmail.com\'); alert("- JavaScript Injected -"); //');

file_put_contents("output.html", $tpl->fetch('page1.tpl'));
